@@ -4,10 +4,12 @@
 与えられた文書からマルコフ連鎖のためのチェーン（連鎖）を作成して、DBに保存するファイル
 '''
 
+import os
 import re
 import sqlite3
-import sys
+import subprocess
 from collections import defaultdict
+from shutil import which
 
 import MeCab
 
@@ -19,25 +21,41 @@ class PrepareChain(object):
 
     BEGIN = '__BEGIN_SENTENCE__'
     END = '__END_SENTENCE__'
-    DB_PATH = 'chain.db'
 
-    def __init__(self, text):
+    def __init__(self, text, DB_PATH='chain.db'):
         '''
         初期化メソッド
         @param text チェーンを生成するための文章
         '''
         self.text = text
+        self.DB_PATH = DB_PATH
 
         # 形態素解析用タガー
-        try:
-            asdf = MeCab.Tagger('-Ochasen')
-        except RuntimeError as e:
-            print(type(e), 'change rc: /etc/mecabrc', file=sys.stderr)
-            asdf = MeCab.Tagger('-Ochasen -r /etc/mecabrc')
-
+        asdf = MeCab.Tagger('-Ochasen -r' + self.search_mecabrc())
         asdf.parse('')
         self.tagger = asdf
 
+    def search_mecabrc(self):
+        if which('mecab-config'):
+            p = subprocess.check_output(
+                ["mecab-config", "--sysconfdir"], shell=False
+            ).decode().rstrip()
+            return os.path.join(p, 'mecabrc')
+        else:
+            return self._search_mecabrc()
+
+    def _search_mecabrc(self):
+        if os.name == 'nt':
+            mecabrc = ('C:\\Program Files(x86)\\Mecab\\etc\\mecabrc',)
+        else:
+            mecabrc = ('/usr/local/etc/mecabrc', '/etc/mecabrc')
+
+        mecabrc = list(filter(os.path.isfile, mecabrc))
+        if len(mecabrc) == 1:
+            return mecabrc[0]
+        else:
+            return ('NUL' if os.name == 'nt' else '/dev/null')
+
     def make_triplet_freqs(self):
         '''
         形態素解析から3つ組の出現回数まで
@@ -113,11 +131,11 @@ class PrepareChain(object):
             triplet_freqs[triplet] += 1
 
         # beginを追加
-        triplet = (PrepareChain.BEGIN, morphemes[0], morphemes[1])
+        triplet = (self.BEGIN, morphemes[0], morphemes[1])
         triplet_freqs[triplet] = 1
 
         # endを追加
-        triplet = (morphemes[-2], morphemes[-1], PrepareChain.END)
+        triplet = (morphemes[-2], morphemes[-1], self.END)
         triplet_freqs[triplet] = 1
 
         return triplet_freqs
@@ -128,7 +146,7 @@ class PrepareChain(object):
         @param triplet_freqs 3つ組とその出現回数の辞書 key: 3つ組（タプル） val: 出現回数
         '''
         # DBオープン
-        con = sqlite3.connect(PrepareChain.DB_PATH)
+        con = sqlite3.connect(self.DB_PATH)
 
         # 初期化から始める場合
         if init:
